@@ -40,7 +40,7 @@ func printResultsTableMarkdown(b formatters.ConfigurableFormatter, title string,
 	_, _ = fmt.Fprintf(b.Writer(), "|---|----|----------|-------|----------|-------------|\n")
 	for i, result := range results {
 		desc := strings.ReplaceAll(result.Description(), "\n", "<br>")
-		location := fmt.Sprintf("%s:%d", b.Path(result), result.Range().GetStartLine())
+		location := fmt.Sprintf("%s:%d", b.Path(result, result.Metadata()), result.Range().GetStartLine())
 		if result.Range().GetEndLine() > result.Range().GetStartLine() {
 			location = fmt.Sprintf("%s-%d", location, result.Range().GetEndLine())
 		}
